@@ -14,7 +14,7 @@ import sys
 from messager.utils import RABBIT_MQ_CREDENTIAL_PROBLEM
 from messager.utils import RABBIT_MQ_CONNECTION_PROBLEM
 from messager.utils import INCORRECT_MESSAGE, MISSING_SITE_ID
-from messager.utils import MISSING_NON_DST_TIMEZONE, MISSING_DEVICE_ID
+from messager.utils import MISSING_NON_DST_TIMEZONE, MISSING_VARIABLE_ID
 from messager.utils import MISSING_DST_TIMEZONE, MISSING_DATE
 from messager.utils import MISSING_MESSAGE
 from time import tzname
@@ -35,8 +35,8 @@ def validate_message(message):
         validated_message = json.loads(message)
         if "siteID" not in validated_message:
             error = INCORRECT_MESSAGE % MISSING_SITE_ID % message
-        elif "deviceID" not in validated_message:
-            error = INCORRECT_MESSAGE % MISSING_DEVICE_ID % message
+        elif "variableID" not in validated_message:
+            error = INCORRECT_MESSAGE % MISSING_VARIABLE_ID % message
         elif "message" not in validated_message:
             error = INCORRECT_MESSAGE % MISSING_MESSAGE % message
         elif "date" not in validated_message:
@@ -152,7 +152,7 @@ class RabbitMQMessager(object):
         # We create our phase message
         json_message = {
             'siteID': site_name,
-            'deviceID': var_name,
+            'variableID': var_name,
             'message': data,
             'date': datetime.utcnow().isoformat('T'),
             'dstTimezone': tzname[1],
