@@ -37,7 +37,7 @@ this configuration: username: %s, password: %s, host: %s"
 CURRENTCOST_UNICODE_ERROR = "Bad message sent from currentcost, invalid ASCII"
 INCORRECT_MESSAGE = "Receive incorrect message => %s"
 MISSING_SITE_ID = "missing siteID in %s"
-MISSING_DEVICE_ID = "missing deviceID in %s"
+MISSING_VARIABLE_ID = "missing deviceID in %s"
 MISSING_MESSAGE = "missing message in %s"
 MISSING_DATE = "missing date in %s"
 MISSING_DST_TIMEZONE = "missing dstTimezone in %s"
